pub fn mark_cli_process()Expand description
Mark this process as the stackless CLI entrypoint (stackless::cli::run).
Spawning the operator daemon (and registering launchd / running the reaper) is only valid from a process that has called this.
pub fn mark_cli_process()Mark this process as the stackless CLI entrypoint (stackless::cli::run).
Spawning the operator daemon (and registering launchd / running the reaper) is only valid from a process that has called this.